Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactBootstrap = require('react-bootstrap');

var _reduxModal = require('redux-modal');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * A `react-bootstrap` `Modal` component which wraps a component
 * This component is placed inside {@link ModalWrapper} so that it
 * can be connected to the `redux` state
 * @param {any} props React props
 * * `handleHide` - function to handle hiding the modal dialog
 * * `title` - Title which gets displayed in the modal dialog
 * * `show` - flag to indicate if the modal is showing or not
 * * `component` - Component to be wrapped in the modal
 * @return {React.ComponentClass} React component which contains
 * the modal and the wrapped component
 */
var InnerModal = function InnerModal(_ref) {
  var handleHide = _ref.handleHide,
      title = _ref.title,
      show = _ref.show,
      Component = _ref.component,
      props = _objectWithoutProperties(_ref, ['handleHide', 'title', 'show', 'component']);

  return _react2['default'].createElement(
    _reactBootstrap.Modal,
    { show: show, onHide: handleHide },
    _react2['default'].createElement(
      _reactBootstrap.Modal.Header,
      null,
      _react2['default'].createElement(
        _reactBootstrap.Modal.Title,
        null,
        title
      )
    ),
    _react2['default'].createElement(
      _reactBootstrap.Modal.Body,
      null,
      _react2['default'].createElement(Component, props)
    )
  );
};

InnerModal.propTypes = {
  handleHide: _propTypes2['default'].func.isRequired,
  show: _propTypes2['default'].bool.isRequired,
  component: _propTypes2['default'].element.isRequired,
  title: _propTypes2['default'].string
};

InnerModal.defaultProps = {
  title: ''
};

var PropertyInjector = function PropertyInjector(component) {
  return function (props) {
    return InnerModal(Object.assign({ component: component }, props));
  };
};

/**
 * A wrapper component for the modal dialog
 * This component connects the modal dialog to the redux state
 * @param {any} props React props
 * * `component` - The component to be wrapped by the modal
 * * `name` - The name of the dialog. This field translates to field under the
 * `modal` state
 * * `destroyOnHide` - flag to indicate whether the component gets destroyed
 * when the modal closes or not
 * * `resolve` - a resolver function to resolve before the dialog is displayed
 * @return {React.ComponentClass} A react component which
 * wraps the modal dialog
 */
var ModalWrapper = function ModalWrapper(_ref2) {
  var component = _ref2.component,
      props = _objectWithoutProperties(_ref2, ['component']);

  var ModalWithProps = PropertyInjector(component);
  var WrappedModal = (0, _reduxModal.connectModal)(props)(ModalWithProps);

  return _react2['default'].createElement(WrappedModal, null);
};

ModalWrapper.propTypes = {
  name: _propTypes2['default'].string.isRequired,
  resolve: _propTypes2['default'].func,
  destroyOnHide: _propTypes2['default'].bool,
  component: _propTypes2['default'].element.isRequired
};

ModalWrapper.defaultProps = {
  destroyOnHide: false,
  resolve: function () {
    function resolve() {
      return null;
    }

    return resolve;
  }()
};

exports['default'] = ModalWrapper;